Gitea
=====

`Gitea <https://gitea.io/>`__ is available at `gitea.example.com` with a CI available at `woodpecker.example.com`.
The user with administrative rights is `root`. Its password can be set
as documented in `this file
<https://lab.enough.community/main/infrastructure/-/blob/master/playbooks/gitea/roles/gitea/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/group_vars/gitea-service-group.yml`
file.
